pub fn install(binary_package: BinaryPackage) -> Result<String>Expand description
Install the provided binary package if it has not been built already.
pub fn install(binary_package: BinaryPackage) -> Result<String>Install the provided binary package if it has not been built already.